const {
  api_country_prefix,
  api_user_distributor,
  api_crm_degree_list,
  api_linkage_cities,
  api_crm_add_chance
} = require('../../utils/api.js');
const {
  net
} = require('../../utils/net.js');
const {
  formatMonth
} = require('../../utils/time.js');
const {
  validator
} = require('../../utils/util.js');

Page({
  data: {
    numberList: [],
    numberIndex: 0,
    userName: '',
    showTrader: false,
    showAdviser: false,
    showTraderDefault: true,
    showAdviserDefault: true,
    showDegreeDefault: true,
    traderList: [],
    traderIndex: 0,
    adviserList: [],
    adviserIndex: 0,
    degreeList: [],
    degreeIndex: -1,
    currMonth: formatMonth(new Date),
    time: '',
    showCityDefault: true,
    cityData: [
      [],
      [],
      []
    ],
    cityIndex: [0, 0, 0],
    tradeName: '',
    traderId: '',
    adviserName: '',
    adviserId: '',
    sex: 0,
    btnDisabled: false
  },
  pageData: {

  },
  onLoad: function (options) {
    const userInfo = wx.getStorageSync('userInfo')
    let showTrader, showAdviser
    // 渠道
    if (userInfo.userType === 1) {
      showTrader = true
    }
    if (userInfo.userType === 2) {
      showAdviser = true
    }

    this.getCityData()

    Promise.all([net.req({
      url: api_country_prefix
    }), (showTrader || showAdviser) ? net.req({
      url: api_user_distributor,
      data: {
        pid: userInfo.id
      }
    }) :
      Promise.resolve(), net.req({
        url: api_crm_degree_list
      })
    ]).then(res => {
      let index = 0,
        list
      res[0].data.forEach((item, i) => {
        item.label = `(${item.prefix})` + item.name
        if (item.prefix == '+86') {
          index = i
        }
      })
      if (res[1] && res[1].data.totalCount) {
        list = res[1].data.list
      }
      this.setData({
        numberList: res[0].data,
        numberIndex: index,
        userName: userInfo.nickName || '',
        degreeList: res[2].data
      }, () => {
        if (userInfo.userType === 1) {
          this.setData({
            userName: "渠道-" + userInfo.nickName,
            traderList: list || [],
            showTrader: showTrader && list ? showTrader : false,
          })
          wx.setStorageSync('traderList', list);
        } else if (userInfo.userType === 2) {
          this.setData({
            userName: "分销商-" + userInfo.nickName,
            adviserList: list || [],
            showAdviser: showAdviser && list ? showAdviser : false,
          })
          wx.setStorageSync('adviserList', list);
        }
      })

    })
  },
  // 后两级第一个数据
  getCityData() {
    net.req({
      url: api_linkage_cities
    }).then(first => {
      net.req({
        url: api_linkage_cities,
        data: {
          pid: first.data[0].id
        }
      }).then(second => {
        net.req({
          url: api_linkage_cities,
          data: {
            pid: second.data[0].id
          }
        }).then(third => {
          this.setData({
            'cityData[0]': first.data,
            'cityData[1]': second.data || [],
            'cityData[2]': third.data || []
          })
        })
      })
    })
  },
  numberChange(e) {
    this.setData({
      numberIndex: e.detail.value
    })
  },
  traderChange(e) {
    const choosed = this.data.traderList[e.detail.value]
    let showAdviser = false
    if (choosed.userType === '2') {
      net.req({
        url: api_user_distributor,
        data: {
          pid: choosed.id
        }
      }).then(res => {
        this.setData({
          showAdviser: res.data.totalCount ? true : false,
        })
      })
    }
    this.setData({
      showAdviser: showAdviser,
      adviserIndex: 0,
      showTraderDefault: false,
      traderIndex: e.detail.value
    })
  },
  adviserChange(e) {
    this.setData({
      showAdviserDefault: false,
      adviserIndex: e.detail.value
    })
  },
  bindCityChange(e) {
    this.setData({
      showCityDefault: false,
      cityIndex: e.detail.value
    })
  },
  bindCityColumnChange(e) {
    const column = e.detail.column // 列
    const value = e.detail.value // 列index
    const pid = this.data.cityData[column][value].id
    const indexArr = this.data.cityIndex
    // 第一列
    if (column === 0) {
      indexArr[0] = value
      indexArr[1] = 0
      indexArr[2] = 0

      net.req({
        url: api_linkage_cities,
        data: {
          pid: pid
        }
      }).then(second => {
        // 二级为空
        if (!second.data) {
          this.setData({
            'cityData[1]': [],
            'cityData[2]': []
          })
        } else {
          this.setData({
            cityIndex: indexArr,
            'cityData[1]': second.data
          })
          // 再请求三级
          net.req({
            url: api_linkage_cities,
            data: {
              pid: second.data[0].id
            }
          }).then(third => {
            this.setData({
              'cityData[2]': third.data || []
            })
          })
        }
      })
    }
    if (column === 1) {
      indexArr[1] = value
      indexArr[2] = 0
      net.req({
        url: api_linkage_cities,
        data: {
          pid: pid
        }
      }).then(third => {
        this.setData({
          cityIndex: indexArr,
          'cityData[2]': third.data || []
        })
      })
    }
  },
  timeChange(e) {
    this.setData({
      time: e.detail.value
    })
  },
  degreeChange(e) {
    this.setData({
      showDegreeDefault: false,
      degreeIndex: e.detail.value
    })
  },

  checkUserNickname: (s) => { /*校验昵称格式是否正确*/
    if (s) {
      s = s.replace(/\s/g, "");
      var rule = /^[A-Za-z0-9\u4e00-\u9fa5]{2,20}$/;
      return rule.test(s);
    }
    return false;
  },

  formSubmit(e) {
    const tempForm = e.detail.value
    if (!this.checkUserNickname(tempForm.nickName)) {
      return this.showErrorMsg('姓名或昵称（2~20位，由字母或数字或汉字组成）')
    }
    if (!this.data.sex) {
      return this.showErrorMsg('性别为必选项')
    }
    if (!validator.checkMobile(tempForm.mobile) && !tempForm.wechat && !tempForm.qq) {
      return this.showErrorMsg('手机号/微信/QQ 至少一项不能为空')
    }
    if (tempForm.cityIndex.join('') === '000' && this.data.showCityDefault) {
      return this.showErrorMsg('意向城市为必选项')
    }
    if (!tempForm.tempDate) {
      return this.showErrorMsg('入住时间为必选项')
    }
    this.setData({
      btnDisabled: true
    });
    tempForm.countryId = this.data.cityData[0][tempForm.cityIndex[0]].id
    tempForm.provinceId = this.data.cityData[1].length && this.data.cityData[1][tempForm.cityIndex[1]].id || 0
    tempForm.cityId = this.data.cityData[2].length && this.data.cityData[2][tempForm.cityIndex[2]].id || 0
    tempForm.prefixMobile = this.data.numberList[tempForm.numberIndex].id
    tempForm.traderId = this.data.traderId
    tempForm.adviserId = this.data.showAdviser ? this.data.adviserId : ""
    tempForm.liveTime = (new Date(tempForm.tempDate)).getTime() ? (new Date(tempForm.tempDate)).getTime() / 1000 : ''
    tempForm.degree = tempForm.degreeIndex == -1 ? 0 : this.data.degreeList[tempForm.degreeIndex].val
    tempForm.sex = this.data.sex
    net.req({
      url: api_crm_add_chance,
      data: tempForm
    },true).then(res => {
      if (res.code === 0) {
        wx.showToast({
          title: '保存成功',
          icon: 'success',
          duration: 2000
        })
        setTimeout(_ => {
          wx.navigateBack()
        }, 2000)
      }
    },(e)=>{
      wx.showToast({
        title: e.msg || 'error',
        icon: 'none',
        duration: 2000
      });
      this.setData({
        btnDisabled: false
      });
    })
  },
  showErrorMsg(msg) {
    wx.showToast({
      title: msg,
      icon: 'none',
      duration: 2000
    })
  },
  onReady: function () {
    wx.setNavigationBarTitle({
      title: '新增客户'
    })
  },
  onShow: function () {

  },
  onHide: function () {

  },
  goList(event) {
    let {
      type
    } = event.currentTarget.dataset
    wx.navigateTo({
      url: `/pages/distributor/distributor?type=${type}`
    })
  },
  getAdviserList(pid) {

    let _this = this
    let params = {
      url: api_user_distributor,
      data: {
        pid
      }
    }
    net.req(params).then((res) => {
      let { list } = res.data
      this.setData({
        adviserList: list
      })
      if (list.length > 0) {
        wx.setStorageSync('adviserList', list);
      }
    })
  },
  searchListCallack(res, type) {
    let {
      userName,
      id,
      userType
    } = res
    if (type === "trade") {
      this.setData({
        tradeName: "分销商-" + userName,
        traderId: id,
        adviserName: '',
        adviserId: ''
      })
      if (userType == "4") {
        this.setData({
          adviserName: "顾问-" + userName,
        })
      } else if (userType == "2") {
        this.setData({
          showAdviser: true,
        })
        this.getAdviserList(id);
      } else {
        this.setData({
          showAdviser: false
        })
      }
    } else if (type === "adviser") {
      this.setData({
        adviserName: "顾问-" + userName,
        adviserId: id
      })
    }
  },

  tapSexAction(e) {
    const { sexIndex } = e.currentTarget.dataset;
    this.setData({
      sex: parseInt(sexIndex)
    })
  }
})