const {
  api_mobile_logout,
  api_upload_file,
  api_update_photo
} = require('../../utils/api.js');
const {
  net
} = require('../../utils/net.js');
const util = require('../../utils/util.js');

Page({
  data: {
    data: {},
    mobile: '',
    phone: '400-898-6659'
  },
  onLoad: function (options) {
    let userInfo = util.getStorageSync('userInfo');
    let conf = util.getStorageSync('conf');
    if (userInfo) {
      this.setData({
        data: userInfo
      }, () => {
        this.setData({
          mobile: `${userInfo.mobile.slice(0, 3)}****${userInfo.mobile.slice(-4)}`
        })
      })
    }
    if (conf) {
      this.setData({
        phone: conf.telCn
      })
    }
  },
  onReady: function () {
    wx.setNavigationBarTitle({
      title: '我的',
    });
  },

  // 登出
  logout() {
    wx.showModal({
      title: '提示',
      content: '确认退出当前账号？',
      success: (res) => {
        if (res.confirm) {
          let params = {};
          params.url = api_mobile_logout;
          net.req(params).then((res) => { });
          wx.clearStorageSync();
          wx.showToast({
            title: '退出成功',
            icon: 'none',
            duration: 1000
          });
          setTimeout(() => {
            wx.reLaunch({
              url: "/pages/loginways/loginways"
            });
          }, 1000);
        }
      }
    })
  },
  // 查看分销商/分销顾问
  toDetail() {
    if (this.data.data.userType == 1) {
      wx.navigateTo({
        url: `/pages/mydistributors/mydistributors`
      })
    } else if (this.data.data.userType == 2) {
      wx.navigateTo({
        url: `/pages/myadvisers/myadvisers`
      })
    }
  },
  // 打电话
  handleMakePhone() {
    let _this = this;
    let systemInfo = util.getStorageSync('systemInfo');
    if (!systemInfo) {
      systemInfo = wx.getSystemInfoSync();
      if (systemInfo) {
        wx.setStorageSync('systemInfo', systemInfo);
      }
    }
    let { system } = systemInfo;
    if (system.toLowerCase().indexOf('ios') !== -1) {
      wx.makePhoneCall({
        phoneNumber: _this.data.phone
      });
    } else {
      wx.showActionSheet({
        itemList: [_this.data.phone],
        success(res) {
          if (res.tapIndex === 0) {
            wx.makePhoneCall({
              phoneNumber: _this.data.phone
            });
          }
        }
      });
    }
  },
  changeUserPhoto() {
    const _this = this;
    wx.showActionSheet({
      itemList: ['从相册中', '拍照'],
      success(res) {
        if (res.tapIndex == 0) {
          _this.chooseImage("album");
        } else {
          _this.chooseImage("camera");
        }
      },
      fail(res) {
      }
    })
  },
  chooseImage(type) {
    const _this = this;
    wx.chooseImage({
      count: 1,
      sizeType: ['original', 'compressed'],
      sourceType: [type],
      success(res) {
        // tempFilePath可以作为img标签的src属性显示图片
        _this.uploadImage(res.tempFilePaths[0]);
      }
    })
  },
  uploadImage(filePath) {
    wx.showLoading({
      title: '正在上传头像',
    });
    let params = {};
    params.url = api_upload_file;
    params.filePath = filePath;
    params.data = {
      "project": "distributors",
      "contentType": 'user/head'
    }
    net.uploadFile(params).then((res) => {
      const { host, url } = res.data;
      if (Array.isArray(url) && url.length) {
        const imgSrc = host + url[0];
        this.uploadImgUrlToServer(imgSrc);
      } else {
        wx.hideLoading()
      }

    }, (err) => {
      wx.hideLoading()
    });
  },

  uploadImgUrlToServer(imgUrl) {
    let params = {};
    params.url = api_update_photo;
    params.data = {
      avatar: imgUrl
    }
    net.req(params).then((res) => {
      let userInfo = this.data.data;
      userInfo.avatar = imgUrl;
      userInfo.changeImg = true; // 标识用户修改了头像，在home的onShow页面需要用到
      this.setData({
        data: userInfo
      });
      //获取页面栈 
      wx.setStorageSync('userInfo', userInfo);
      wx.hideLoading()
    });
  }
})